@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="146"/>
+        <location filename="retext.py" line="175"/>
         <source>Enter your Google account data</source>
         <translation>Introduzca los datos de su cuenta de Google</translation>
     </message>
     <message>
-        <location filename="retext.py" line="155"/>
+        <location filename="retext.py" line="184"/>
         <source>Username</source>
         <translation>Usuario</translation>
     </message>
     <message>
-        <location filename="retext.py" line="156"/>
+        <location filename="retext.py" line="185"/>
         <source>Password</source>
         <translation>Contraseña</translation>
     </message>
@@ -21,167 +21,187 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="216"/>
+        <location filename="retext.py" line="245"/>
         <source>File toolbar</source>
         <translation>Barra de archivos</translation>
     </message>
     <message>
-        <location filename="retext.py" line="218"/>
+        <location filename="retext.py" line="247"/>
         <source>Edit toolbar</source>
         <translation>Barra de edición</translation>
     </message>
     <message>
-        <location filename="retext.py" line="220"/>
+        <location filename="retext.py" line="249"/>
         <source>Search toolbar</source>
         <translation>Barra de búsqueda</translation>
     </message>
     <message>
-        <location filename="retext.py" line="222"/>
+        <location filename="retext.py" line="251"/>
         <source>New</source>
         <translation>Nuevo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="226"/>
+        <location filename="retext.py" line="253"/>
         <source>Open</source>
         <translation>Abrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="230"/>
+        <location filename="retext.py" line="255"/>
         <source>Save</source>
         <translation>Guardar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="235"/>
+        <location filename="retext.py" line="258"/>
         <source>Save as</source>
         <translation>Guardar cómo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="238"/>
+        <location filename="retext.py" line="260"/>
         <source>Print</source>
         <translation>Imprimir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="242"/>
+        <location filename="retext.py" line="262"/>
         <source>Print preview</source>
         <translation>Vista preliminar de impresión</translation>
     </message>
     <message>
-        <location filename="retext.py" line="244"/>
+        <location filename="retext.py" line="264"/>
         <source>View HTML code</source>
         <translation>Ver código HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="246"/>
+        <location filename="retext.py" line="265"/>
         <source>Change default font</source>
         <translation>Cambiar fuente predeterminada</translation>
     </message>
     <message>
-        <location filename="retext.py" line="248"/>
+        <location filename="retext.py" line="266"/>
         <source>Find text</source>
         <translation>Buscar texto</translation>
     </message>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="270"/>
         <source>Preview</source>
         <translation>Vista preliminar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="279"/>
         <source>Live preview</source>
         <translation>Vista preliminar en vivo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="269"/>
+        <location filename="retext.py" line="281"/>
         <source>Fullscreen mode</source>
         <translation>Pantalla completa</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="288"/>
         <source>Other formats</source>
         <translation>Otros formatos</translation>
     </message>
     <message>
-        <location filename="retext.py" line="287"/>
+        <location filename="retext.py" line="294"/>
         <source>Quit</source>
         <translation>Salir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="291"/>
+        <location filename="retext.py" line="297"/>
         <source>Undo</source>
         <translation>Deshacer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="293"/>
+        <location filename="retext.py" line="299"/>
         <source>Redo</source>
         <translation>Rehacer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="301"/>
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="300"/>
+        <location filename="retext.py" line="303"/>
         <source>Cut</source>
         <translation>Cortar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="305"/>
         <source>Paste</source>
         <translation>Pegar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="319"/>
+        <location filename="retext.py" line="315"/>
         <source>Enable</source>
         <translation>Activar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="321"/>
+        <location filename="retext.py" line="316"/>
         <source>Set locale</source>
         <translation>Establecer local</translation>
     </message>
     <message>
-        <location filename="retext.py" line="332"/>
+        <location filename="retext.py" line="325"/>
         <source>Plain text</source>
         <translation>Texto plano</translation>
     </message>
     <message>
-        <location filename="retext.py" line="338"/>
+        <location filename="retext.py" line="327"/>
+        <source>Use WebKit renderer</source>
+        <translation>Usar intérprete Webkit</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="334"/>
         <source>Generate webpages</source>
         <translation>Generar páginas web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="340"/>
+        <location filename="retext.py" line="335"/>
         <source>Show</source>
         <translation>Mostrar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="342"/>
+        <location filename="retext.py" line="336"/>
         <source>Next</source>
         <translation>Siguiente</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="337"/>
         <source>Previous</source>
         <translation>Anterior</translation>
     </message>
     <message>
-        <location filename="retext.py" line="348"/>
+        <location filename="retext.py" line="339"/>
         <source>Get help online</source>
         <translation>Obtener ayuda en-línea</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
-        <source>About %1</source>
-        <translation>Acerca de %1</translation>
+        <location filename="retext.py" line="344"/>
+        <source>About %s</source>
+        <translation>Acerca de %s</translation>
     </message>
     <message>
-        <location filename="retext.py" line="353"/>
+        <location filename="retext.py" line="347"/>
         <source>About Qt</source>
         <translation>Acerca de Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="374"/>
+        <location filename="retext.py" line="368"/>
+        <source>Bold</source>
+        <translation>Negrita</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="369"/>
+        <source>Italic</source>
+        <translation>Cursiva</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="370"/>
+        <source>Underline</source>
+        <translation>Subrayado</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="373"/>
         <source>Save to Google Docs</source>
         <translation>Guardar en Google Docs</translation>
     </message>
@@ -196,234 +216,244 @@
         <translation>Símbolos</translation>
     </message>
     <message>
-        <location filename="retext.py" line="398"/>
+        <location filename="retext.py" line="408"/>
         <source>File</source>
         <translation>Archivo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="399"/>
+        <location filename="retext.py" line="409"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="400"/>
+        <location filename="retext.py" line="410"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="retext.py" line="764"/>
+        <location filename="retext.py" line="413"/>
         <source>Open recent</source>
         <translation>Abrir recientes</translation>
     </message>
     <message>
-        <location filename="retext.py" line="404"/>
+        <location filename="retext.py" line="416"/>
         <source>Directory</source>
         <translation>Directorio</translation>
     </message>
     <message>
-        <location filename="retext.py" line="412"/>
+        <location filename="retext.py" line="424"/>
         <source>Export</source>
         <translation>Exportar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="433"/>
+        <location filename="retext.py" line="450"/>
         <source>Spell check</source>
         <translation>Revisar ortografía</translation>
     </message>
     <message>
-        <location filename="retext.py" line="441"/>
+        <location filename="retext.py" line="458"/>
         <source>Default editing mode</source>
         <translation>Modo de edición por defecto</translation>
     </message>
     <message>
-        <location filename="retext.py" line="476"/>
+        <location filename="retext.py" line="461"/>
+        <source>Formatting</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="499"/>
         <source>Search</source>
         <translation>Buscar</translation>
     </message>
     <message>
-        <location filename="retext.py" line="480"/>
+        <location filename="retext.py" line="503"/>
         <source>Case sensitively</source>
         <translation>Distinguir mayúsculas/minúsculas</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1122"/>
+        <location filename="retext.py" line="1330"/>
         <source>New document</source>
         <translation>Nuevo documento</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>¡No tiene ni el módulo Markdown ni Docutils instalados!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>Only HTML formatting will be available.</source>
         <translation>Sólo estará disponible el formato HTML.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="646"/>
+        <location filename="retext.py" line="726"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Introduzca el nombre del local (por ejemplo: en_US)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="735"/>
+        <location filename="retext.py" line="813"/>
         <source>Please, save the file somewhere.</source>
         <translation>Salve el fichero en algún lugar.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="722"/>
+        <location filename="retext.py" line="800"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Páginas web guardadas en el directorio &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="724"/>
+        <location filename="retext.py" line="802"/>
         <source>Show directory</source>
         <translation>Mostrar directorio</translation>
     </message>
     <message>
-        <location filename="retext.py" line="729"/>
+        <location filename="retext.py" line="807"/>
         <source>Webpages generator is not installed!</source>
         <translation>¡El generador de páginas web no está instalado!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Select one or several files to open</source>
         <translation>Seleccione uno o varios archivos a abrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Supported files</source>
         <translation>Archivos soportados</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>All files (*)</source>
         <translation>Todos los archivos (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="824"/>
+        <location filename="retext.py" line="984"/>
         <source>Plain text (*.txt)</source>
         <translation>Texto plano (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="827"/>
+        <location filename="retext.py" line="987"/>
         <source>ReStructuredText files</source>
         <translation>Archivos ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="830"/>
+        <location filename="retext.py" line="990"/>
         <source>HTML files</source>
         <translation>Archivos HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="833"/>
+        <location filename="retext.py" line="993"/>
         <source>Markdown files</source>
         <translation>Archivos Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>Save file</source>
         <translation>Guardar archivo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="847"/>
+        <location filename="retext.py" line="1008"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>¡No se puede guardar el archivo porque está como sólo-lectura!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>Export document to ODT</source>
         <translation>Exportar documento a ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Archivos de texto OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Archivos HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>Export document to PDF</source>
         <translation>Exportar documento a PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>PDF files (*.pdf)</source>
         <translation>Archivos PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="946"/>
+        <location filename="retext.py" line="1109"/>
         <source>Print document</source>
         <translation>Imprimir documento</translation>
     </message>
     <message>
-        <location filename="retext.py" line="968"/>
+        <location filename="retext.py" line="1128"/>
         <source>Export document</source>
         <translation>Exportar documento</translation>
     </message>
     <message>
-        <location filename="retext.py" line="963"/>
+        <location filename="retext.py" line="1151"/>
+        <source>Failed to execute the command:</source>
+        <translation>Fallo al ejecutar el comando:</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1158"/>
         <source>This function is not available in Plain text mode!</source>
         <translation>¡Esta función no está disponible en modo Texto plano!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="966"/>
+        <location filename="retext.py" line="1161"/>
         <source>Select type</source>
         <translation>Seleccione tipo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1035"/>
+        <location filename="retext.py" line="1224"/>
         <source>Incorrect user name or password!</source>
         <translation>¡Nombre de usuario o contraseña incorrectos!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1038"/>
+        <location filename="retext.py" line="1227"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>¡Autenticación fallida. Compruebe su conexión a internet!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1100"/>
+        <location filename="retext.py" line="1299"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>El documento ha sido modificado.
 ¿Quiere guardar sus cambios?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1125"/>
+        <location filename="retext.py" line="1337"/>
         <source>HTML code</source>
         <translation>Código HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Sencillo pero potente editor para Markdown y ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Website</source>
         <translation>Sitio web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Markdown syntax</source>
         <translation>Sintaxis Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>ReST syntax</source>
         <translation>Sintaxis ReST</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1187"/>
+        <location filename="retext.py" line="1411"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>¡No se pudo analizar el contenido del archivo. Compruebe si tiene los módulos necesarios instalados!</translation>
     </message>
