@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="146"/>
+        <location filename="retext.py" line="175"/>
         <source>Enter your Google account data</source>
         <translation>Entrez vos données du compte Google</translation>
     </message>
     <message>
-        <location filename="retext.py" line="155"/>
+        <location filename="retext.py" line="184"/>
         <source>Username</source>
         <translation>Utilisateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="156"/>
+        <location filename="retext.py" line="185"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
@@ -21,172 +21,172 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="1122"/>
+        <location filename="retext.py" line="1330"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="216"/>
+        <location filename="retext.py" line="245"/>
         <source>File toolbar</source>
         <translation>Barre d&apos;outil Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="218"/>
+        <location filename="retext.py" line="247"/>
         <source>Edit toolbar</source>
         <translation>Barre d&apos;outil Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="220"/>
+        <location filename="retext.py" line="249"/>
         <source>Search toolbar</source>
         <translation>Barre d&apos;outil Rechercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="222"/>
+        <location filename="retext.py" line="251"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="retext.py" line="226"/>
+        <location filename="retext.py" line="253"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="230"/>
+        <location filename="retext.py" line="255"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="235"/>
+        <location filename="retext.py" line="258"/>
         <source>Save as</source>
         <translation>Enregistrer Sous</translation>
     </message>
     <message>
-        <location filename="retext.py" line="238"/>
+        <location filename="retext.py" line="260"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="242"/>
+        <location filename="retext.py" line="262"/>
         <source>Print preview</source>
         <translation>Aperçu d&apos;impression</translation>
     </message>
     <message>
-        <location filename="retext.py" line="244"/>
+        <location filename="retext.py" line="264"/>
         <source>View HTML code</source>
         <translation>Voir code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="246"/>
+        <location filename="retext.py" line="265"/>
         <source>Change default font</source>
         <translation>Changer police par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="248"/>
+        <location filename="retext.py" line="266"/>
         <source>Find text</source>
         <translation>Chercher text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="270"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="279"/>
         <source>Live preview</source>
         <translation>Aperçu live</translation>
     </message>
     <message>
-        <location filename="retext.py" line="269"/>
+        <location filename="retext.py" line="281"/>
         <source>Fullscreen mode</source>
         <translation>Mode plein écran</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="288"/>
         <source>Other formats</source>
         <translation>Autres formats</translation>
     </message>
     <message>
-        <location filename="retext.py" line="287"/>
+        <location filename="retext.py" line="294"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="291"/>
+        <location filename="retext.py" line="297"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="retext.py" line="293"/>
+        <location filename="retext.py" line="299"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="301"/>
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="300"/>
+        <location filename="retext.py" line="303"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="305"/>
         <source>Paste</source>
         <translation>Coller</translation>
     </message>
     <message>
-        <location filename="retext.py" line="319"/>
+        <location filename="retext.py" line="315"/>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="321"/>
+        <location filename="retext.py" line="316"/>
         <source>Set locale</source>
         <translation>choisir langue</translation>
     </message>
     <message>
-        <location filename="retext.py" line="332"/>
+        <location filename="retext.py" line="325"/>
         <source>Plain text</source>
         <translation>Format Text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="764"/>
+        <location filename="retext.py" line="413"/>
         <source>Open recent</source>
         <translation>Ouvrir récent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="338"/>
+        <location filename="retext.py" line="334"/>
         <source>Generate webpages</source>
         <translation>Générer pages web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="340"/>
+        <location filename="retext.py" line="335"/>
         <source>Show</source>
         <translation>Montrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="342"/>
+        <location filename="retext.py" line="336"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="337"/>
         <source>Previous</source>
         <translation>Précédent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="348"/>
+        <location filename="retext.py" line="339"/>
         <source>Get help online</source>
         <translation>Aide en ligne</translation>
     </message>
     <message>
-        <location filename="retext.py" line="353"/>
+        <location filename="retext.py" line="347"/>
         <source>About Qt</source>
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="374"/>
+        <location filename="retext.py" line="373"/>
         <source>Save to Google Docs</source>
         <translation>Enregistrer sur Google Docs</translation>
     </message>
@@ -201,231 +201,261 @@
         <translation>Symboles</translation>
     </message>
     <message>
-        <location filename="retext.py" line="398"/>
+        <location filename="retext.py" line="408"/>
         <source>File</source>
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="399"/>
+        <location filename="retext.py" line="409"/>
         <source>Edit</source>
         <translation>Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="400"/>
+        <location filename="retext.py" line="410"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="retext.py" line="404"/>
+        <location filename="retext.py" line="416"/>
         <source>Directory</source>
         <translation>Répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="412"/>
+        <location filename="retext.py" line="424"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="433"/>
+        <location filename="retext.py" line="450"/>
         <source>Spell check</source>
         <translation>Vérificateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="441"/>
+        <location filename="retext.py" line="458"/>
         <source>Default editing mode</source>
         <translation>Mode d&apos;édition par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="476"/>
+        <location filename="retext.py" line="499"/>
         <source>Search</source>
         <translation>Chercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="480"/>
+        <location filename="retext.py" line="503"/>
         <source>Case sensitively</source>
         <translation>Respect de la casse</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>Vous n&apos;avez pas Markdown, ni Docutils d&apos;installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>Only HTML formatting will be available.</source>
         <translation>Seulement le format HTML sera disponible.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="646"/>
+        <location filename="retext.py" line="726"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Entrez le préfix pour la lagnue (exemple: fr_FR)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="735"/>
+        <location filename="retext.py" line="813"/>
         <source>Please, save the file somewhere.</source>
         <translation>SVP, enregistrer le fichier quelque part.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="722"/>
+        <location filename="retext.py" line="800"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Pages enregistrés dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Select one or several files to open</source>
         <translation>choisir un ou plusieurs fichiers pour ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Supported files</source>
         <translation>Formats supportés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>All files (*)</source>
         <translation>Tous fichiers (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="824"/>
+        <location filename="retext.py" line="984"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichier text (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="827"/>
+        <location filename="retext.py" line="987"/>
         <source>ReStructuredText files</source>
         <translation>Fichiers ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="830"/>
+        <location filename="retext.py" line="990"/>
         <source>HTML files</source>
         <translation>Fichiers HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="833"/>
+        <location filename="retext.py" line="993"/>
         <source>Markdown files</source>
         <translation>Fichiers Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>Save file</source>
         <translation>Enregistrer fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>Export document to ODT</source>
         <translation>Exporter document vers ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichier text OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichier HTML (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>Export document to PDF</source>
         <translation>Exporter document vers PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="946"/>
+        <location filename="retext.py" line="1109"/>
         <source>Print document</source>
         <translation>Imprimer document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="963"/>
+        <location filename="retext.py" line="1158"/>
         <source>This function is not available in Plain text mode!</source>
         <translation>Cette fonctionnalité n&apos;est pas disponible en mode Texte !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="966"/>
+        <location filename="retext.py" line="1161"/>
         <source>Select type</source>
         <translation>Choisir Type</translation>
     </message>
     <message>
-        <location filename="retext.py" line="968"/>
+        <location filename="retext.py" line="1128"/>
         <source>Export document</source>
         <translation>Exporter document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1035"/>
+        <location filename="retext.py" line="1224"/>
         <source>Incorrect user name or password!</source>
         <translation>Utilisateur ou mot de passe incorrect !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1100"/>
+        <location filename="retext.py" line="1299"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a changé.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1125"/>
+        <location filename="retext.py" line="1337"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Éditeur de Markdown et ReStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur :Dmity Schachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>ReST syntax</source>
         <translation>Syntaxe Rest</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1187"/>
+        <location filename="retext.py" line="1411"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>Ne peut analyser le contenu du fichier, vérifier si les modules sont bien installés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="724"/>
+        <location filename="retext.py" line="802"/>
         <source>Show directory</source>
         <translation>Montrer répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="729"/>
+        <location filename="retext.py" line="807"/>
         <source>Webpages generator is not installed!</source>
         <translation>Générateur Webpages non installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="847"/>
+        <location filename="retext.py" line="1008"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Ne peut enregistrer le fichier car en lecture seule !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1038"/>
+        <location filename="retext.py" line="1227"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>Authentification echouée, svp vérifier votre connection internet !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
-        <source>About %1</source>
-        <translation>À propos de %1</translation>
+        <location filename="retext.py" line="368"/>
+        <source>Bold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="369"/>
+        <source>Italic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="370"/>
+        <source>Underline</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="461"/>
+        <source>Formatting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="344"/>
+        <source>About %s</source>
+        <translation>À propos de %s</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="327"/>
+        <source>Use WebKit renderer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1151"/>
+        <source>Failed to execute the command:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
