@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="146"/>
+        <location filename="retext.py" line="175"/>
         <source>Enter your Google account data</source>
         <translation>Googleアカウントデータを入力してください</translation>
     </message>
     <message>
-        <location filename="retext.py" line="155"/>
+        <location filename="retext.py" line="184"/>
         <source>Username</source>
         <translation>ユーザー名</translation>
     </message>
     <message>
-        <location filename="retext.py" line="156"/>
+        <location filename="retext.py" line="185"/>
         <source>Password</source>
         <translation>パスワード</translation>
     </message>
@@ -21,172 +21,172 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="1122"/>
+        <location filename="retext.py" line="1330"/>
         <source>New document</source>
         <translation>新規文書</translation>
     </message>
     <message>
-        <location filename="retext.py" line="216"/>
+        <location filename="retext.py" line="245"/>
         <source>File toolbar</source>
         <translation>ファイルツールバー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="218"/>
+        <location filename="retext.py" line="247"/>
         <source>Edit toolbar</source>
         <translation>編集ツールバー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="220"/>
+        <location filename="retext.py" line="249"/>
         <source>Search toolbar</source>
         <translation>検索ツールバー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="222"/>
+        <location filename="retext.py" line="251"/>
         <source>New</source>
         <translation>新規</translation>
     </message>
     <message>
-        <location filename="retext.py" line="226"/>
+        <location filename="retext.py" line="253"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="retext.py" line="230"/>
+        <location filename="retext.py" line="255"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="retext.py" line="235"/>
+        <location filename="retext.py" line="258"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="retext.py" line="238"/>
+        <location filename="retext.py" line="260"/>
         <source>Print</source>
         <translation>印刷</translation>
     </message>
     <message>
-        <location filename="retext.py" line="242"/>
+        <location filename="retext.py" line="262"/>
         <source>Print preview</source>
         <translation>印刷プレビュー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="244"/>
+        <location filename="retext.py" line="264"/>
         <source>View HTML code</source>
         <translation>HTMLコードを表示</translation>
     </message>
     <message>
-        <location filename="retext.py" line="246"/>
+        <location filename="retext.py" line="265"/>
         <source>Change default font</source>
         <translation>規定のフォントを変更</translation>
     </message>
     <message>
-        <location filename="retext.py" line="248"/>
+        <location filename="retext.py" line="266"/>
         <source>Find text</source>
         <translation>テキストを検索</translation>
     </message>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="270"/>
         <source>Preview</source>
         <translation>プレビュー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="279"/>
         <source>Live preview</source>
         <translation>ライブプレビュー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="269"/>
+        <location filename="retext.py" line="281"/>
         <source>Fullscreen mode</source>
         <translation>フルスクリーンモード</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="288"/>
         <source>Other formats</source>
         <translation>その他のフォーマット</translation>
     </message>
     <message>
-        <location filename="retext.py" line="287"/>
+        <location filename="retext.py" line="294"/>
         <source>Quit</source>
         <translation>終了</translation>
     </message>
     <message>
-        <location filename="retext.py" line="291"/>
+        <location filename="retext.py" line="297"/>
         <source>Undo</source>
         <translation>元に戻す</translation>
     </message>
     <message>
-        <location filename="retext.py" line="293"/>
+        <location filename="retext.py" line="299"/>
         <source>Redo</source>
         <translation>やり直す</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="301"/>
         <source>Copy</source>
         <translation>コピー</translation>
     </message>
     <message>
-        <location filename="retext.py" line="300"/>
+        <location filename="retext.py" line="303"/>
         <source>Cut</source>
         <translation>切り取り</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="305"/>
         <source>Paste</source>
         <translation>貼り付け</translation>
     </message>
     <message>
-        <location filename="retext.py" line="319"/>
+        <location filename="retext.py" line="315"/>
         <source>Enable</source>
         <translation>有効</translation>
     </message>
     <message>
-        <location filename="retext.py" line="321"/>
+        <location filename="retext.py" line="316"/>
         <source>Set locale</source>
         <translation>ロケールの設定</translation>
     </message>
     <message>
-        <location filename="retext.py" line="332"/>
+        <location filename="retext.py" line="325"/>
         <source>Plain text</source>
         <translation>プレーンテキスト</translation>
     </message>
     <message>
-        <location filename="retext.py" line="764"/>
+        <location filename="retext.py" line="413"/>
         <source>Open recent</source>
         <translation>最近使用したファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="338"/>
+        <location filename="retext.py" line="334"/>
         <source>Generate webpages</source>
         <translation>Webページを生成</translation>
     </message>
     <message>
-        <location filename="retext.py" line="340"/>
+        <location filename="retext.py" line="335"/>
         <source>Show</source>
         <translation>表示</translation>
     </message>
     <message>
-        <location filename="retext.py" line="342"/>
+        <location filename="retext.py" line="336"/>
         <source>Next</source>
         <translation>次へ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="337"/>
         <source>Previous</source>
         <translation>前へ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="348"/>
+        <location filename="retext.py" line="339"/>
         <source>Get help online</source>
         <translation>オンラインでヘルプを読む</translation>
     </message>
     <message>
-        <location filename="retext.py" line="353"/>
+        <location filename="retext.py" line="347"/>
         <source>About Qt</source>
         <translation>Qtについて</translation>
     </message>
     <message>
-        <location filename="retext.py" line="374"/>
+        <location filename="retext.py" line="373"/>
         <source>Save to Google Docs</source>
         <translation>Google Docsに保存</translation>
     </message>
@@ -201,231 +201,261 @@
         <translation>シンボル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="398"/>
+        <location filename="retext.py" line="408"/>
         <source>File</source>
         <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="399"/>
+        <location filename="retext.py" line="409"/>
         <source>Edit</source>
         <translation>編集</translation>
     </message>
     <message>
-        <location filename="retext.py" line="400"/>
+        <location filename="retext.py" line="410"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="404"/>
+        <location filename="retext.py" line="416"/>
         <source>Directory</source>
         <translation>ディレクトリ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="412"/>
+        <location filename="retext.py" line="424"/>
         <source>Export</source>
         <translation>エクスポート</translation>
     </message>
     <message>
-        <location filename="retext.py" line="433"/>
+        <location filename="retext.py" line="450"/>
         <source>Spell check</source>
         <translation>スペルチェック</translation>
     </message>
     <message>
-        <location filename="retext.py" line="441"/>
+        <location filename="retext.py" line="458"/>
         <source>Default editing mode</source>
         <translation>規定の編集モード</translation>
     </message>
     <message>
-        <location filename="retext.py" line="476"/>
+        <location filename="retext.py" line="499"/>
         <source>Search</source>
         <translation>検索</translation>
     </message>
     <message>
-        <location filename="retext.py" line="480"/>
+        <location filename="retext.py" line="503"/>
         <source>Case sensitively</source>
         <translation>大文字と小文字を区別</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>MarkdownとDocutilsモジュールがインストールされています!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>Only HTML formatting will be available.</source>
         <translation>HTMLフォーマットのみ利用可能です.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="646"/>
+        <location filename="retext.py" line="726"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>ロケール名を入力 (例: en_US)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="735"/>
+        <location filename="retext.py" line="813"/>
         <source>Please, save the file somewhere.</source>
         <translation>どこかにファイルを保存してください.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="722"/>
+        <location filename="retext.py" line="800"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Webページを&lt;code&gt;html&lt;/code&gt;ディレクトリに保存しました.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="724"/>
+        <location filename="retext.py" line="802"/>
         <source>Show directory</source>
         <translation>ディレクトリを表示</translation>
     </message>
     <message>
-        <location filename="retext.py" line="729"/>
+        <location filename="retext.py" line="807"/>
         <source>Webpages generator is not installed!</source>
         <translation>Webページジェネレーターがインストールされていません!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Select one or several files to open</source>
         <translation>開くには一つまたは複数のファイルを選択します</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Supported files</source>
         <translation>サポートされているファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>All files (*)</source>
         <translation>すべてのファイル (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="824"/>
+        <location filename="retext.py" line="984"/>
         <source>Plain text (*.txt)</source>
         <translation>プレーンテキスト (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="827"/>
+        <location filename="retext.py" line="987"/>
         <source>ReStructuredText files</source>
         <translation>ReStructuredTextファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="830"/>
+        <location filename="retext.py" line="990"/>
         <source>HTML files</source>
         <translation>HTMLファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="833"/>
+        <location filename="retext.py" line="993"/>
         <source>Markdown files</source>
         <translation>Markdownファイル</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>Save file</source>
         <translation>ファイルを保存</translation>
     </message>
     <message>
-        <location filename="retext.py" line="847"/>
+        <location filename="retext.py" line="1008"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>読み取り専用ファイルなので保存できません!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>Export document to ODT</source>
         <translation>文書をODTにエクスポート</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocumentテキストファイル (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTMLファイル (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>Export document to PDF</source>
         <translation>文書をPDFにエクスポート</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDFファイル (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="946"/>
+        <location filename="retext.py" line="1109"/>
         <source>Print document</source>
         <translation>文書を印刷</translation>
     </message>
     <message>
-        <location filename="retext.py" line="963"/>
+        <location filename="retext.py" line="1158"/>
         <source>This function is not available in Plain text mode!</source>
         <translation>プレーンテキストモードではこの関数を使用できません!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="966"/>
+        <location filename="retext.py" line="1161"/>
         <source>Select type</source>
         <translation>タイプを選択</translation>
     </message>
     <message>
-        <location filename="retext.py" line="968"/>
+        <location filename="retext.py" line="1128"/>
         <source>Export document</source>
         <translation>文書をエクスポート</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1035"/>
+        <location filename="retext.py" line="1224"/>
         <source>Incorrect user name or password!</source>
         <translation>ユーザー名またはパスワードが違います!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1038"/>
+        <location filename="retext.py" line="1227"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>認証に失敗しました。インターネットへの接続を確認してください!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1100"/>
+        <location filename="retext.py" line="1299"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>文書は変更されています.
 変更内容を保存しますか?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1125"/>
+        <location filename="retext.py" line="1337"/>
         <source>HTML code</source>
         <translation>HTMLコード</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>MarkdownとReStructuredTextのためのシンプルで強力なエディタ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Website</source>
         <translation>Webサイト</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Markdown syntax</source>
         <translation>Markdown記法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>ReST syntax</source>
         <translation>ReST記法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1187"/>
+        <location filename="retext.py" line="1411"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>ファイル内容が解析できません。必要なモジュールがインストールされているか確認してください!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
-        <source>About %1</source>
-        <translation>%1 について</translation>
+        <location filename="retext.py" line="327"/>
+        <source>Use WebKit renderer</source>
+        <translation>WebKitレンダラーを使用</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="344"/>
+        <source>About %s</source>
+        <translation>%s について</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="368"/>
+        <source>Bold</source>
+        <translation>太字</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="369"/>
+        <source>Italic</source>
+        <translation>斜体</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="370"/>
+        <source>Underline</source>
+        <translation>下線</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="461"/>
+        <source>Formatting</source>
+        <translation>書式</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1151"/>
+        <source>Failed to execute the command:</source>
+        <translation>コマンドの実行に失敗しました:</translation>
     </message>
 </context>
 </TS>
