@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="146"/>
+        <location filename="retext.py" line="175"/>
         <source>Enter your Google account data</source>
         <translation>請輸入您的 Google 帳號訊息</translation>
     </message>
     <message>
-        <location filename="retext.py" line="155"/>
+        <location filename="retext.py" line="184"/>
         <source>Username</source>
         <translation>用戶名</translation>
     </message>
     <message>
-        <location filename="retext.py" line="156"/>
+        <location filename="retext.py" line="185"/>
         <source>Password</source>
         <translation>密鑰或應用程式碼（適用于兩步式認証的 Google 帳號）</translation>
     </message>
@@ -21,22 +21,22 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="226"/>
+        <location filename="retext.py" line="253"/>
         <source>Open</source>
         <translation>開啟</translation>
     </message>
     <message>
-        <location filename="retext.py" line="230"/>
+        <location filename="retext.py" line="255"/>
         <source>Save</source>
         <translation>儲存</translation>
     </message>
     <message>
-        <location filename="retext.py" line="238"/>
+        <location filename="retext.py" line="260"/>
         <source>Print</source>
         <translation>列印</translation>
     </message>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="270"/>
         <source>Preview</source>
         <translation>預覽</translation>
     </message>
@@ -51,380 +51,410 @@
         <translation>特殊符號</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 檔案 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="913"/>
+        <location filename="retext.py" line="1071"/>
         <source>Save file</source>
         <translation>儲存檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="235"/>
+        <location filename="retext.py" line="258"/>
         <source>Save as</source>
         <translation>另存新檔</translation>
     </message>
     <message>
-        <location filename="retext.py" line="287"/>
+        <location filename="retext.py" line="294"/>
         <source>Quit</source>
         <translation>離開</translation>
     </message>
     <message>
-        <location filename="retext.py" line="353"/>
+        <location filename="retext.py" line="347"/>
         <source>About Qt</source>
         <translation>關於 Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="398"/>
+        <location filename="retext.py" line="408"/>
         <source>File</source>
         <translation>檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="399"/>
+        <location filename="retext.py" line="409"/>
         <source>Edit</source>
         <translation>編輯</translation>
     </message>
     <message>
-        <location filename="retext.py" line="400"/>
+        <location filename="retext.py" line="410"/>
         <source>Help</source>
         <translation>說明</translation>
     </message>
     <message>
-        <location filename="retext.py" line="412"/>
+        <location filename="retext.py" line="424"/>
         <source>Export</source>
         <translation>匯出</translation>
     </message>
     <message>
-        <location filename="retext.py" line="216"/>
+        <location filename="retext.py" line="245"/>
         <source>File toolbar</source>
         <translation>檔案工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="218"/>
+        <location filename="retext.py" line="247"/>
         <source>Edit toolbar</source>
         <translation>編輯工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>Export document to PDF</source>
         <translation>匯出檔案到 PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1094"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 檔案 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1100"/>
+        <location filename="retext.py" line="1299"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>檔案已變更，確定儲存嗎？</translation>
     </message>
     <message>
-        <location filename="retext.py" line="291"/>
+        <location filename="retext.py" line="297"/>
         <source>Undo</source>
         <translation>復原</translation>
     </message>
     <message>
-        <location filename="retext.py" line="293"/>
+        <location filename="retext.py" line="299"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="301"/>
         <source>Copy</source>
         <translation>複製</translation>
     </message>
     <message>
-        <location filename="retext.py" line="300"/>
+        <location filename="retext.py" line="303"/>
         <source>Cut</source>
         <translation>剪下</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="305"/>
         <source>Paste</source>
         <translation>貼上</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1122"/>
+        <location filename="retext.py" line="1330"/>
         <source>New document</source>
         <translation>新檔</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>All files (*)</source>
         <translation>所有檔案 (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="222"/>
+        <location filename="retext.py" line="251"/>
         <source>New</source>
         <translation>新增</translation>
     </message>
     <message>
-        <location filename="retext.py" line="764"/>
+        <location filename="retext.py" line="413"/>
         <source>Open recent</source>
         <translation>開啟最近的</translation>
     </message>
     <message>
-        <location filename="retext.py" line="332"/>
+        <location filename="retext.py" line="325"/>
         <source>Plain text</source>
         <translation>純文本</translation>
     </message>
     <message>
-        <location filename="retext.py" line="374"/>
+        <location filename="retext.py" line="373"/>
         <source>Save to Google Docs</source>
         <translation>匯出到 Google Docs</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1035"/>
+        <location filename="retext.py" line="1224"/>
         <source>Incorrect user name or password!</source>
         <translation>用戶名或密鑰不正確!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Libreoffice 檔案 (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="904"/>
+        <location filename="retext.py" line="1062"/>
         <source>Export document to ODT</source>
         <translation>匯出檔案到 ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="244"/>
+        <location filename="retext.py" line="264"/>
         <source>View HTML code</source>
         <translation>檢視 HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1125"/>
+        <location filename="retext.py" line="1337"/>
         <source>HTML code</source>
         <translation>HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="retext.py" line="242"/>
+        <location filename="retext.py" line="262"/>
         <source>Print preview</source>
         <translation>列印預覽</translation>
     </message>
     <message>
-        <location filename="retext.py" line="946"/>
+        <location filename="retext.py" line="1109"/>
         <source>Print document</source>
         <translation>列印檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="279"/>
         <source>Live preview</source>
         <translation>同步預覽</translation>
     </message>
     <message>
-        <location filename="retext.py" line="722"/>
+        <location filename="retext.py" line="800"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>網頁儲存在 &lt;code&gt;html&lt;/code&gt; 目錄。</translation>
     </message>
     <message>
-        <location filename="retext.py" line="735"/>
+        <location filename="retext.py" line="813"/>
         <source>Please, save the file somewhere.</source>
         <translation>請，儲存到別的地方呦！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="338"/>
+        <location filename="retext.py" line="334"/>
         <source>Generate webpages</source>
         <translation>產生網頁</translation>
     </message>
     <message>
-        <location filename="retext.py" line="824"/>
+        <location filename="retext.py" line="984"/>
         <source>Plain text (*.txt)</source>
         <translation>純文本 (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="340"/>
+        <location filename="retext.py" line="335"/>
         <source>Show</source>
         <translation>顯示</translation>
     </message>
     <message>
-        <location filename="retext.py" line="404"/>
+        <location filename="retext.py" line="416"/>
         <source>Directory</source>
         <translation>目錄</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Supported files</source>
         <translation>支持的檔案格式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="246"/>
+        <location filename="retext.py" line="265"/>
         <source>Change default font</source>
         <translation>變更預設字型</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="288"/>
         <source>Other formats</source>
         <translation>其他格式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="966"/>
+        <location filename="retext.py" line="1161"/>
         <source>Select type</source>
         <translation>選擇類型</translation>
     </message>
     <message>
-        <location filename="retext.py" line="968"/>
+        <location filename="retext.py" line="1128"/>
         <source>Export document</source>
         <translation>匯出檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="963"/>
+        <location filename="retext.py" line="1158"/>
         <source>This function is not available in Plain text mode!</source>
         <translation>該功能無法在純文本模式下使用！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>Only HTML formatting will be available.</source>
         <translation>只有 HTML 格式才供應。</translation>
     </message>
     <message>
-        <location filename="retext.py" line="319"/>
+        <location filename="retext.py" line="315"/>
         <source>Enable</source>
         <translation>啟用</translation>
     </message>
     <message>
-        <location filename="retext.py" line="321"/>
+        <location filename="retext.py" line="316"/>
         <source>Set locale</source>
         <translation>選擇程式語言</translation>
     </message>
     <message>
-        <location filename="retext.py" line="433"/>
+        <location filename="retext.py" line="450"/>
         <source>Spell check</source>
         <translation>拼寫檢查</translation>
     </message>
     <message>
-        <location filename="retext.py" line="646"/>
+        <location filename="retext.py" line="726"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>輸入語言名字 (例如: en_US)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="269"/>
+        <location filename="retext.py" line="281"/>
         <source>Fullscreen mode</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="retext.py" line="220"/>
+        <location filename="retext.py" line="249"/>
         <source>Search toolbar</source>
         <translation>尋找工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="248"/>
+        <location filename="retext.py" line="266"/>
         <source>Find text</source>
         <translation>尋找文本</translation>
     </message>
     <message>
-        <location filename="retext.py" line="342"/>
+        <location filename="retext.py" line="336"/>
         <source>Next</source>
         <translation>下一條</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="337"/>
         <source>Previous</source>
         <translation>上一條</translation>
     </message>
     <message>
-        <location filename="retext.py" line="441"/>
+        <location filename="retext.py" line="458"/>
         <source>Default editing mode</source>
         <translation>預設編輯模式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="476"/>
+        <location filename="retext.py" line="499"/>
         <source>Search</source>
         <translation>尋找</translation>
     </message>
     <message>
-        <location filename="retext.py" line="480"/>
+        <location filename="retext.py" line="503"/>
         <source>Case sensitively</source>
         <translation>對大小写敏感</translation>
     </message>
     <message>
-        <location filename="retext.py" line="497"/>
+        <location filename="retext.py" line="526"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>你既沒有安裝 Markdown 也没有 Docutils 模塊!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="830"/>
+        <location filename="retext.py" line="990"/>
         <source>HTML files</source>
         <translation>HTML 檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Website</source>
         <translation>部落格</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Markdown syntax</source>
         <translation>Markdown 句法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>ReST syntax</source>
         <translation>ReST 句法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="827"/>
+        <location filename="retext.py" line="987"/>
         <source>ReStructuredText files</source>
         <translation>ReStructuredText 檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="833"/>
+        <location filename="retext.py" line="993"/>
         <source>Markdown files</source>
         <translation>Markdown 檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
+        <location filename="retext.py" line="1346"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>簡單高效的 Markdown 與 ReStructuredText 編輯器</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1187"/>
+        <location filename="retext.py" line="1411"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>不能處理檔案內容，檢查你是否安裝了必要的模塊！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="769"/>
+        <location filename="retext.py" line="929"/>
         <source>Select one or several files to open</source>
         <translation>選擇一個或多個檔案以開啟</translation>
     </message>
     <message>
-        <location filename="retext.py" line="348"/>
+        <location filename="retext.py" line="339"/>
         <source>Get help online</source>
         <translation>在線擷取幫助（英文）</translation>
     </message>
     <message>
-        <location filename="retext.py" line="724"/>
+        <location filename="retext.py" line="802"/>
         <source>Show directory</source>
         <translation>顯示目錄</translation>
     </message>
     <message>
-        <location filename="retext.py" line="729"/>
+        <location filename="retext.py" line="807"/>
         <source>Webpages generator is not installed!</source>
         <translation>網頁生成器未安裝！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="847"/>
+        <location filename="retext.py" line="1008"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>不能儲存檔案因为它是只讀的！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1038"/>
+        <location filename="retext.py" line="1227"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>驗証失敗，請核查您的網絡連接！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1134"/>
-        <source>About %1</source>
-        <translation>關於 %1</translation>
+        <location filename="retext.py" line="368"/>
+        <source>Bold</source>
+        <translation>加粗</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="369"/>
+        <source>Italic</source>
+        <translation>傾斜</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="370"/>
+        <source>Underline</source>
+        <translation>下劃線</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="461"/>
+        <source>Formatting</source>
+        <translation>樣式</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="344"/>
+        <source>About %s</source>
+        <translation>關於 %s</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="327"/>
+        <source>Use WebKit renderer</source>
+        <translation>使用WebKit渲染</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1151"/>
+        <source>Failed to execute the command:</source>
+        <translation>不能執行指令:</translation>
     </message>
 </context>
 </TS>
