@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # ReText webpages generator
-# Copyright 2011 Dmitry Shachnev
+# Copyright 2011-2012 Dmitry Shachnev
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ import shutil
 
 try:
 	import markdown
-	md = markdown.Markdown()
 except:
 	use_md = False
 else:
@@ -39,7 +38,7 @@ else:
 	use_docutils = True
 
 app_name = "ReText Webpages generator"
-app_version = "0.4.3"
+app_version = "0.5.3"
 app_site = "http://sourceforge.net/p/retext/"
 
 if os.path.exists("/usr/share/wpgen/"):
@@ -60,18 +59,32 @@ class WebLibrary(object):
 	def updateAll(self):
 		"""Process all documents in the directory"""
 		self._initTemplate()
+		self._initExtensions()
 		for fname in filter(os.path.isfile, os.listdir(self.dirPath)):
 			self._processPage(fname)
 	
 	def update(self, fileName):
 		"""Process fileName file in the directory"""
 		self._initTemplate()
+		self._initExtensions()
 		if os.path.exists(self.dirPath+"/"+fileName):
 			self._processPage(fileName)
 	
+	def _initExtensions(self):
+		self.extensions = []
+		extspath = self.dirPath+"/markdown-extensions.txt"
+		if os.path.exists(extspath):
+			extsfile = open(extspath)
+			self.extensions = [ext.rstrip() for ext in extsfile]
+			extsfile.close()
+	
 	def _initTemplate(self):
 		templatefile = open(self.dirPath+"/template.html", "r")
-		self.template = unicode(templatefile.read(), 'utf-8')
+		try:
+			self.template = unicode(templatefile.read(), 'utf-8')
+		except:
+			# For Python 3
+			self.template = templatefile.read()
 		templatefile.close()
 		self.template = self.template.replace("%GENERATOR%", app_name + " " + app_version)
 		self.template = self.template.replace("%APPINFO%", "<a href=\""+ app_site + "\">" + app_name + "</a>")
@@ -79,11 +92,20 @@ class WebLibrary(object):
 	def _processPage(self, fname):
 		bn, ext = os.path.splitext(fname)
 		html = pagename = ''
+		md = markdown.Markdown(self.extensions)
 		inputfile = open(self.dirPath+"/"+fname, "r")
-		text = unicode(inputfile.read(), 'utf-8')
+		try:
+			text = unicode(inputfile.read(), 'utf-8')
+		except:
+			# For Python 3
+			text = inputfile.read()
 		inputfile.close()
 		if ext in (".md", ".mkd", ".re") and use_md:
 			html = md.convert(text)
+			try:
+				pagename = str.join(' ', md.Meta['title'])
+			except:
+				pass
 		elif ext in (".rst", ".rest") and use_docutils:
 			parts = publish_parts(text, writer_name='html')
 			html = parts['body']
@@ -95,17 +117,23 @@ class WebLibrary(object):
 			pagename = bn
 		if html or bn == "index":
 			content = self.template
+			content = content.replace("%CONTENT%", html)
 			try:
 				pagename = unicode(pagename, 'utf-8')
 				bn = unicode(bn, 'utf-8')
 			except:
+				# Not needed for Python 3
 				pass
-			content = content.replace("%CONTENT%", html)
 			content = content.replace("%PAGENAME%", pagename)
+			content = content.replace("%HTMLDIR%", ".")
 			content = content.replace(" href=\""+bn+".html\"", "")
 			content = content.replace("%\\", "%")
 			outputfile = open(self.dirPath+"/html/"+bn+".html", "w")
-			outputfile.write(content.encode('utf-8'))
+			try:
+				outputfile.write(content.encode('utf-8'))
+			except:
+				# For Python 3
+				outputfile.write(content)
 			outputfile.close()
 
 def main(argv):
@@ -125,9 +153,6 @@ def main(argv):
 				os.mkdir("html")
 			shutil.copy(templates_dir+"template_Default.html", "template.html")
 			shutil.copy(templates_dir+"style_Default.css", "html/style.css")
-			if not (os.path.exists("index.mkd") or os.path.exists("index.rst")):
-				index = open("index.mkd", "w")
-				index.close()
 		elif argv[1] == "usestyle" and len(argv) == 3:
 			if os.path.exists(templates_dir+"style_"+argv[2]+".css"):
 				shutil.copy(templates_dir+"style_"+argv[2]+".css", "html/style.css")
